==> v12.0.7.zip: fvtt-rolemaster-frp/module/config.js <==
export const rmss = {};

rmss.currency_type = {
  mp: "rmss.curreny_type.mp",
  pp: "rmss.curreny_type.pp",
  gp: "rmss.curreny_type.gp",
  sp: "rmss.curreny_type.sp",
  bp: "rmss.curreny_type.bp",
  cp: "rmss.curreny_type.cp"
};

rmss.difficulties = {
  routine: {key: "routine", label:"Routine (+30)", value: 30},
  easy: {key: "easy", label:"Easy (+20)", value: 20},
  light: {key: "light", label:"Light (+10)", value: 10},
  medium: {key: "medium", label:"Medium (0)", value: 0},
  hard: {key: "hard", label:"Hard (-10)", value: -10},
  very_hard: {key: "very_hard", label:"Very Hard (-20)", value: -20},
  extremely_hard: {key: "extremely_hard", label:"Extremely Hard (-30)", value: -30},
  sheer_folly: {key: "sheer_folly", label:"Sheer Folly (-50)", value: -50},
  absurd: {key: "absurd", label:"Absurd (-70)", value: -70},
};

rmss.combatSituations = [
  {key: "none", label:"None (0)", modifier: 0},
  {key: "melee", label:"Melee environment (-20)", modifier: -20},
  {key: "missile", label:"Under missile fire (-10)", modifier: -10},
];

rmss.rankBonusProgressionList = [
  {key: "standard", label:"Standard"},
  {key: "limited", label:"Limited"},
  {key: "combined", label:"Combined"},
  {key: "race", label:"Linked to Race"},
]

rmss.lightOrDarknessModifiers = [
   {key: "none", label:"None", modifierLight: 0, modifierDark: 0},
   {key: "noshadows", label:"No shadows", modifierLight: 10, modifierDark: -30},
   {key: "lightshadows", label:"Light shadows", modifierLight: 5, modifierDark: -20},
   {key: "mediumshadows", label:"Medium shadows", modifierLight: 0, modifierDark: 0},
   {key: "heavyshadows", label:"Heavy shadows", modifierLight: -10, modifierDark: 10},
   {key: "dark", label:"Darkness", modifierLight: -25, modifierDark: 30},
   {key: "pitchblack", label:"Pitch black", modifierLight: -40, modifierDark: 40},
]

rmss.hitsPerRound = [
  {key: "none", label:"None", modifier: 0},
  {key: "one", label:"One", modifier: -5},
  {key: "two", label:"Two", modifier: -10},
  {key: "three", label:"Three", modifier: -20},
  {key: "four", label:"Four", modifier: -25},
  {key: "five", label:"Five", modifier: -30},
  {key: "six", label:"Six", modifier: -35},
  {key: "seven", label:"Seven", modifier: -40},
  {key: "eight", label:"Eight", modifier: -45},
  {key: "nine", label:"Nine", modifier: -50},
  {key: "ten", label:"Ten", modifier: -55},
  {key: "eleven", label:"Eleven", modifier: -60},
  {key: "twelve", label:"Twelve", modifier: -65},
  {key: "thirteen", label:"Thirteen", modifier: -70},
  {key: "fourteen", label:"Fourteen", modifier: -75},
  {key: "fifteen", label:"Fifteen", modifier: -80}
];

rmss.stats = {
  agility: {
    fullname: "Agility",
    shortname: "Ag"
  },
  constitution: {
    fullname: "Constitution",
    shortname: "Co"
  },
  memory: {
    fullname: "Memory",
    shortname: "Me"
  },
  reasoning: {
    fullname: "Reasoning",
    shortname: "Re"
  },
  self_discipline: {
    fullname: "Self Discipline",
    shortname: "SD"
  },
  empathy: {
    fullname: "Empathy",
    shortname: "Em"
  },
  intuition: {
    fullname: "Intuition",
    shortname: "In"
  },
  presence: {
    fullname: "Presence",
    shortname: "Pr"
  },
  quickness: {
    fullname: "Quickness",
    shortname: "Qu"
  },
  strength: {
    fullname: "Strength",
    shortname: "St"
  }
};

rmss.skill_designations = {
  None: "None",
  Occupational: "Occupational",
  Everyman: "Everyman",
  Restricted: "Restricted"
};

==> v12.0.19.zip: fvtt-rolemaster-frp/module/config.js <==
import {RMFRP_CRITICALS} from "./rmfrp-critical-tables.js";
import {RMFRP_FUMBLES} from "./rmfrp-fumble-tables.js";

export const rmfrp = {};

rmfrp.criticals = RMFRP_CRITICALS;
rmfrp.fumbles = RMFRP_FUMBLES;

rmfrp.currency_type = {
  mp: "rmfrp.curreny_type.mp",
  pp: "rmfrp.curreny_type.pp",
  gp: "rmfrp.curreny_type.gp",
  sp: "rmfrp.curreny_type.sp",
  bp: "rmfrp.curreny_type.bp",
  cp: "rmfrp.curreny_type.cp"
};

rmfrp.difficulties = {
  routine: {key: "routine", label:"Routine (+30)", value: 30},
  easy: {key: "easy", label:"Easy (+20)", value: 20},
  light: {key: "light", label:"Light (+10)", value: 10},
  medium: {key: "medium", label:"Medium (0)", value: 0},
  hard: {key: "hard", label:"Hard (-10)", value: -10},
  very_hard: {key: "very_hard", label:"Very Hard (-20)", value: -20},
  extremely_hard: {key: "extremely_hard", label:"Extremely Hard (-30)", value: -30},
  sheer_folly: {key: "sheer_folly", label:"Sheer Folly (-50)", value: -50},
  absurd: {key: "absurd", label:"Absurd (-70)", value: -70},
};

rmfrp.gameSystems = [
  {key: "common", label:"Common"},
  {key: "merp", label:"Middle Earth Role Playing (MERP)"},
  {key: "rmfrp", label:"Rolemaster Fantasy Role Playing (RMFRP)"},
];

rmfrp.combatSituations = [
  {key: "none", label:"None (0)", modifier: 0},
  {key: "melee", label:"Melee environment (-20)", modifier: -20},
  {key: "missile", label:"Under missile fire (-10)", modifier: -10},
];

rmfrp.rankBonusProgressionList = [
  {key: "standard", label:"Standard"},
  {key: "limited", label:"Limited"},
  {key: "combined", label:"Combined"},
  {key: "race", label:"Linked to Race"},
]

rmfrp.lightOrDarknessModifiers = [
   {key: "none", label:"None", modifierLight: 0, modifierDark: 0},
   {key: "noshadows", label:"No shadows", modifierLight: 10, modifierDark: -30},
   {key: "lightshadows", label:"Light shadows", modifierLight: 5, modifierDark: -20},
   {key: "mediumshadows", label:"Medium shadows", modifierLight: 0, modifierDark: 0},
   {key: "heavyshadows", label:"Heavy shadows", modifierLight: -10, modifierDark: 10},
   {key: "dark", label:"Darkness", modifierLight: -25, modifierDark: 30},
   {key: "pitchblack", label:"Pitch black", modifierLight: -40, modifierDark: 40},
]

rmfrp.hitsPerRound = [
  {key: "none", label:"None", modifier: 0},
  {key: "one", label:"One", modifier: -5},
  {key: "two", label:"Two", modifier: -10},
  {key: "three", label:"Three", modifier: -20},
  {key: "four", label:"Four", modifier: -25},
  {key: "five", label:"Five", modifier: -30},
  {key: "six", label:"Six", modifier: -35},
  {key: "seven", label:"Seven", modifier: -40},
  {key: "eight", label:"Eight", modifier: -45},
  {key: "nine", label:"Nine", modifier: -50},
  {key: "ten", label:"Ten", modifier: -55},
  {key: "eleven", label:"Eleven", modifier: -60},
  {key: "twelve", label:"Twelve", modifier: -65},
  {key: "thirteen", label:"Thirteen", modifier: -70},
  {key: "fourteen", label:"Fourteen", modifier: -75},
  {key: "fifteen", label:"Fifteen", modifier: -80}
];

rmfrp.stats = {
  agility: {
    fullname: "Agility",
    shortname: "Ag"
  },
  constitution: {
    fullname: "Constitution",
    shortname: "Co"
  },
  memory: {
    fullname: "Memory",
    shortname: "Me"
  },
  reasoning: {
    fullname: "Reasoning",
    shortname: "Re"
  },
  self_discipline: {
    fullname: "Self Discipline",
    shortname: "SD"
  },
  empathy: {
    fullname: "Empathy",
    shortname: "Em"
  },
  intuition: {
    fullname: "Intuition",
    shortname: "In"
  },
  presence: {
    fullname: "Presence",
    shortname: "Pr"
  },
  quickness: {
    fullname: "Quickness",
    shortname: "Qu"
  },
  strength: {
    fullname: "Strength",
    shortname: "St"
  }
};

rmfrp.skill_designations = {
  None: "None",
  Occupational: "Occupational",
  Everyman: "Everyman",
  Restricted: "Restricted"
};

rmfrp.armor_values = {
  "1": "1",
  "2": "2",
  "3": "3",
  "4": "4",
  "5": "5",
  "6": "6",
  "7": "7",
  "8": "8",
  "9": "9",
  "10": "10",
  "11": "11",
  "12": "12",
  "13": "13",
  "14": "14",
  "15": "15",
  "16": "16",
  "17": "17",
  "18": "18",
  "19": "19",
  "20": "20"
}

rmfrp.keyToCriticalTable ={
  K: "krush",
  P: "puncture",
  S: "slash",
  U: "unbalance",
  G: "grapple"
}
